@@ -3,8 +3,8 @@
 ;; Author: <github.com/Anoncheg1,codeberg.org/Anoncheg>
 ;; Keywords: org, text, hypermedia, url
 ;; URL: https://github.com/Anoncheg1/emacs-org-links
-;; Package-Version: 20260116.1316
-;; Package-Revision: b1bb0da38ce1
+;; Package-Version: 20260220.2318
+;; Package-Revision: 8f9b49d66244
 ;; Created: 30 Aug 2025
 ;; Package-Requires: ((emacs "27.1"))
 ;; SPDX-License-Identifier: AGPL-3.0-or-later
@@ -95,13 +95,15 @@
 
 ;; Other packages:
 ;; - Modern navigation in major modes https://github.com/Anoncheg1/firstly-search
-;; - Search with Mandarin Chinese pinying https://github.com/Anoncheg1/pinyin-isearch
-;; - Ediff fix			https://github.com/Anoncheg1/ediffnw
+;; - Search with Chinese	https://github.com/Anoncheg1/pinyin-isearch
+;; - Ediff no 3-th window	https://github.com/Anoncheg1/ediffnw
 ;; - Dired history		https://github.com/Anoncheg1/dired-hist
-;; - Mark window with contrast https://github.com/Anoncheg1/selected-window-contrast
-;; - Org hyperlinks enhanced	https://github.com/Anoncheg1/org-links
-;; - Solution for "callback hell"	 https://github.com/Anoncheg1/emacs-async1
-;; - Call LLMs & AIfrom Org-mode block.  https://github.com/Anoncheg1/emacs-oai
+;; - Selected window contrast	https://github.com/Anoncheg1/selected-window-contrast
+;; - Copy link to clipboard	https://github.com/Anoncheg1/emacs-org-links
+;; - Solution for "callback hell"	https://github.com/Anoncheg1/emacs-async1
+;; - Restore buffer state	https://github.com/Anoncheg1/emacs-unmodified-buffer1
+;; - outline.el usage		https://github.com/Anoncheg1/emacs-outline-it
+;; - ai_block for Org mode for chat. https://github.com/Anoncheg1/emacs-oai
 
 ;; *DONATE MONEY* to sponsor author directly with crypto currencies:
 ;; - BTC (Bitcoin) address: 1CcDWSQ2vgqv5LxZuWaHGW52B9fkT5io25
@@ -113,6 +115,7 @@
 ;; - provide option FOR NUM::FUZZY: if several lines found jump to
 ;;   closes to NUM, not to exact NUM.
 ;; - when at <<some>> generate special link without universal arg.
+;; - support multiline links separated at ::
 ;;; Code:
 ;; -=  includes
 (require 'ol)
@@ -188,8 +191,12 @@ Bad handling of [ character, such links should be avoided."
             "::" (org-links-org-link--normalize-string (buffer-substring-no-properties (line-beginning-position) (line-end-position))))))
 
 (defun org-links--create-org-default-at-point ()
-  "Wrap `org-store-link' to extract main parts of link."
-  (let ((link-string (substring-no-properties (org-store-link nil))))
+  "Wrap `org-store-link' to extract main parts of link.
+Used code from `org-babel-tangle--unbracketed-link'."
+  (let ((link-string (substring-no-properties
+                      (cl-letf (((symbol-function 'org-store-link-functions)
+                                 (lambda () nil)))
+                        (org-store-link nil)))))
     ;; - [[ ]]  links
     (if (string-match org-link-bracket-re link-string) ; 1: file::search-option 2: decription
         (let ((path (match-string 1 link-string))
@@ -199,27 +206,6 @@ Bad handling of [ character, such links should be avoided."
          ;; else - other types
          (org-links-create-link link-string))))
 
-;; (defun org-links--create-org-default-at-point ()
-;;   "Wrap `org-store-link' to extract main parts of link."
-;;   (let* ((link-string (substring-no-properties (org-store-link nil)))
-;;          (link (with-temp-buffer
-;;                  (insert link-string)
-;;                  (goto-char 1)
-;;                  (org-element-link-parser)))
-;;          (type (org-element-property :type link))
-;;          (path (org-element-property :path link)))
-
-
-;;   (let ((link-string (substring-no-properties (org-store-link nil))))
-;;     ;; - [[ ]]  links
-;;     (if (string-match org-link-bracket-re link-string) ; 1: file::search-option 2: decription
-;;         (let ((path (match-string 1 link-string))
-;;               (desc (match-string 2 link-string)))
-
-;;           (org-links-create-link path desc))
-;;          ;; else - other types
-;;          (org-links-create-link link-string))))
-
 ;; -=  Copy to clipboard - create link - main
 (defun org-links--create-link-for-region (arg)
   "Create link based on current position for any mode.
@@ -282,9 +268,13 @@ For usage with original Org `org-open-at-point-global' function."
            ;; - Images mode 2
            ((derived-mode-p (intern "image-dired-image-mode"))
             (concat "file:" (buffer-file-name (buffer-base-buffer))))
-           ;; - Images mode 2
+           ;; - Images mode 3
            ((derived-mode-p (intern "image-mode"))
             (concat "file:" (buffer-file-name (buffer-base-buffer))))
+           ;; - Dired
+           ((derived-mode-p (intern "dired-mode"))
+            (string-join (mapcar (lambda (x) (concat "file:" x))
+                                   (funcall (intern "dired-get-marked-files") arg)) " "))
            ;; - Buffer menu
            ((derived-mode-p 'Buffer-menu-mode)
             (concat "file:" (or (buffer-file-name (Buffer-menu-buffer t))
